useCREP | unified-mandala - v1.0.0
Description: Documentation for unified-mandala

# Function useCREP

- useCREP(): {
  history: CREPEntry[];
  triggerCREP: ((data) => void);
  }

- #### Returns {
  history: CREPEntry[];
  triggerCREP: ((data) => void);
  }

  - ##### history: CREPEntry[]

  - ##### triggerCREP: ((data) => void)

    - - (data): void

      - #### Parameters

        - data: {
          C: number;
          E: number;
          P: number;
          R: number;
          }

          - ##### C: number

          - ##### E: number

          - ##### P: number

          - ##### R: number

        #### Returns void

  - Defined in packages/unifiedmandala-ui/hooks/useCREP.ts:8